@@ -1,5 +1,5 @@
 /*
- * $Id: gt_http_client.c,v 1.54 2005/01/04 15:03:40 mkern Exp $
+ * $Id: gt_http_client.c,v 1.57 2006/02/03 20:11:40 mkern Exp $
  *
  * Copyright (C) 2001-2003 giFT project (gift.sourceforge.net)
  *
@@ -205,8 +205,8 @@ void gt_http_client_start (int fd, input_id id, GtTransfer *xfer)
 		gt->connect_failed = TRUE;
 
 		gt_transfer_status (xfer, SOURCE_CANCELLED, (fd == -1 ?
-		                                             "Connection timed out" :
-		                                             GIFT_NETERROR()));
+		                                             "Connect timeout" :
+		                                             "Connect failed"));
 		gt_transfer_close (xfer, TRUE);
 		return;
 	}
@@ -225,8 +225,7 @@ void gt_http_client_start (int fd, input_id id, GtTransfer *xfer)
 	/* send the GET / request to the server */
 	if (client_get_request (xfer) <= 0)
 	{
-		gt_transfer_status (xfer, SOURCE_CANCELLED,
-		                    "Remote host had an aneurism");
+		gt_transfer_status (xfer, SOURCE_CANCELLED, "GET send failed");
 		gt_transfer_close (xfer, TRUE);
 		return;
 	}
@@ -868,7 +867,10 @@ void gt_get_read_file (int fd, input_id id, GtTransfer *xfer)
 
 	if ((recv_len = tcp_recv (c, buf, size)) <= 0)
 	{
-		gt_transfer_status (xfer, SOURCE_CANCELLED, "Connection closed");
+		GT->DBGFN (GT, "tcp_recv error (%d) from %s:%hu: %s", recv_len,
+		           net_ip_str (c->host), c->port,  GIFT_NETERROR());
+
+		gt_transfer_status (xfer, SOURCE_CANCELLED, "Cancelled remotely");
 		gt_transfer_close (xfer, TRUE);
 		return;
 	}
